#include "settingsdialog.h"
#include "ui_settingsdialog.h"

SettingsDialog::SettingsDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::SettingsDialog)
{
    ui->setupUi(this);
    this->setWindowTitle("Settings");
    ui->layersNumber->setValue(Settings::getInstance()->getLayersNumber());
    QString path("Path to root folder of the media tree: /n");
    path.append(Settings::getInstance()->getPathMedia());
    ui->mediaPath->setText(path);

    connect(ui->mediaPatchButton, SIGNAL(clicked()),
            this, SLOT(changeMediaPath()));
    connect(ui->layersNumber, SIGNAL(valueChanged(int)),
            this, SLOT(layersChanged(int)));
    int layer = 0;
    foreach (const dmxSetting &it, Settings::getInstance()->getDmxSettings()) {
        LayerSettingsWidget *temp = new LayerSettingsWidget(this, layer);
        temp->setUniverse(it.universe);
        temp->setAddress(it.address);
        ui->layersLayout->insertWidget(layer, temp);
        layer++;
    }
}

SettingsDialog::~SettingsDialog()
{
    delete ui;
}

void SettingsDialog::changeMediaPath()
{
    QFileDialog dialog(this);
    dialog.setFileMode(QFileDialog::Directory);
    QStringList fileNames;
    if (!dialog.exec())
        return;
    fileNames = dialog.selectedFiles();
    QString file = fileNames.at(0);
    Settings::getInstance()->setPathMedia(file);
    QString desc = tr("Media Path Changed to: %1").arg(file);
    qDebug(desc.toLatin1().constData());
}

void SettingsDialog::layersChanged(int val)
{
    int layers = Settings::getInstance()->getLayersNumber();
    if (val > layers)
    {
      while (val != layers)
      {
         ui->layersLayout->addWidget(new LayerSettingsWidget(this, val));
         layers++;
      }
    } else if (val < layers)
    {
        while (val != layers)
        {
            Settings::getInstance()->removeLayer(val);
            QLayoutItem * const item = ui->layersLayout->itemAt(layers);
            ui->layersLayout->removeItem(item);
            layers--;
        }
    }
    Settings::getInstance()->setLayersNumber(layers);
}
